{
    "$graph": [
        {
            "class": "Workflow",
            "label": "sequence (bam or fastqs) to trimmed fastqs",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#sequence_data.yml/sequence_data",
                            "label": "sequence data with readgroup information",
                            "fields": [
                                {
                                    "type": [
                                        "null",
                                        "string"
                                    ],
                                    "name": "#sequence_data.yml/sequence_data/readgroup"
                                },
                                {
                                    "type": [
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/bam",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/bam/bam"
                                                }
                                            ]
                                        },
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/fastqs",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq1"
                                                },
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq2"
                                                }
                                            ]
                                        }
                                    ],
                                    "name": "#sequence_data.yml/sequence_data/sequence"
                                }
                            ]
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#main/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "id": "#main/adapter_trim_end"
                },
                {
                    "type": "File",
                    "id": "#main/adapters"
                },
                {
                    "type": "int",
                    "id": "#main/max_uncalled"
                },
                {
                    "type": "int",
                    "id": "#main/min_readlength"
                },
                {
                    "type": "#sequence_data.yml/sequence_data",
                    "id": "#main/unaligned"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/unzip_fastqs"
                }
            ],
            "steps": [
                {
                    "run": "#sequence_to_fastq.cwl",
                    "in": [
                        {
                            "source": "#main/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('bam')? self.sequence.bam : null)",
                            "id": "#main/sequence_to_fastq/bam"
                        },
                        {
                            "source": "#main/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq1')? self.sequence.fastq1 : null)",
                            "id": "#main/sequence_to_fastq/fastq1"
                        },
                        {
                            "source": "#main/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq2')? self.sequence.fastq2 : null)",
                            "id": "#main/sequence_to_fastq/fastq2"
                        },
                        {
                            "source": "#main/unzip_fastqs",
                            "id": "#main/sequence_to_fastq/unzip_fastqs"
                        }
                    ],
                    "out": [
                        "#main/sequence_to_fastq/fastq1",
                        "#main/sequence_to_fastq/fastq2"
                    ],
                    "id": "#main/sequence_to_fastq"
                },
                {
                    "run": "#trim_fastq.cwl",
                    "in": [
                        {
                            "source": "#main/adapter_min_overlap",
                            "id": "#main/trim_fastq/adapter_min_overlap"
                        },
                        {
                            "source": "#main/adapter_trim_end",
                            "id": "#main/trim_fastq/adapter_trim_end"
                        },
                        {
                            "source": "#main/adapters",
                            "id": "#main/trim_fastq/adapters"
                        },
                        {
                            "source": "#main/max_uncalled",
                            "id": "#main/trim_fastq/max_uncalled"
                        },
                        {
                            "source": "#main/min_readlength",
                            "id": "#main/trim_fastq/min_readlength"
                        },
                        {
                            "source": "#main/sequence_to_fastq/fastq1",
                            "id": "#main/trim_fastq/reads1"
                        },
                        {
                            "source": "#main/sequence_to_fastq/fastq2",
                            "id": "#main/trim_fastq/reads2"
                        }
                    ],
                    "out": [
                        "#main/trim_fastq/fastqs",
                        "#main/trim_fastq/fastq1",
                        "#main/trim_fastq/fastq2"
                    ],
                    "id": "#main/trim_fastq"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/trim_fastq/fastq1",
                    "id": "#main/fastq1"
                },
                {
                    "type": "File",
                    "outputSource": "#main/trim_fastq/fastq2",
                    "id": "#main/fastq2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/trim_fastq/fastqs",
                    "id": "#main/fastqs"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Picard: BAM to FASTQ",
            "baseCommand": [
                "/bin/bash",
                "makefastqs.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/picard:2.23.6"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        }
                    ]
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "makefastqs.sh",
                            "entry": "set -o pipefail\nset -o errexit\nset -o nounset\n\nUNZIP=false\n\nwhile getopts \":b:1:2:d:u\" opt; do\n    case \"$opt\" in\n        b)\n            MODE=bam\n            BAM=\"$OPTARG\"\n            ;;\n        1)\n            MODE=fastq\n            FASTQ1=\"$OPTARG\"\n            ;;\n        2)  \n            MODE=fastq\n            FASTQ2=\"$OPTARG\"\n            ;;\n        d)\n            OUTDIR=\"$OPTARG\"\n            ;;\n        u)\n            UNZIP=true\n            ;;\n    esac\ndone\n\nif [[ \"$MODE\" == 'fastq' ]]; then #must be fastq input\n\n    if $UNZIP; then\n        if gzip -t $FASTQ1 2> /dev/null; then\n            gunzip -c $FASTQ1 > $OUTDIR/read1.fastq\n        else\n            cp $FASTQ1 $OUTDIR/read1.fastq\n        fi\n\n        if gzip -t $FASTQ2 2> /dev/null; then\n            gunzip -c $FASTQ2 > $OUTDIR/read2.fastq\n        else\n            cp $FASTQ2 $OUTDIR/read2.fastq\n        fi\n    else\n        if gzip -t $FASTQ1 2> /dev/null; then\n            cp $FASTQ1 $OUTDIR/read1.fastq.gz\n        else\n            cp $FASTQ1 $OUTDIR/read1.fastq\n        fi\n\n        if gzip -t $FASTQ2 2> /dev/null; then\n            cp $FASTQ2 $OUTDIR/read2.fastq.gz\n        else\n            cp $FASTQ2 $OUTDIR/read2.fastq\n        fi\n    fi\n\nelse # then\n    ##run samtofastq here, dumping to the same filenames\n    ## input file is $BAM\n    /usr/bin/java -Xmx4g -jar /usr/picard/picard.jar SamToFastq I=\"$BAM\" INCLUDE_NON_PF_READS=true F=$OUTDIR/read1.fastq F2=$OUTDIR/read2.fastq VALIDATION_STRINGENCY=SILENT\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -6,
                    "prefix": "-d"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#sequence_to_fastq.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#sequence_to_fastq.cwl/fastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#sequence_to_fastq.cwl/fastq2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-u"
                    },
                    "doc": "If true, and the input sequence contains gzipped fastqs, they will be unzipped",
                    "id": "#sequence_to_fastq.cwl/unzip_fastqs"
                }
            ],
            "outputs": [
                {
                    "$import": "#sequence_to_fastq.cwl/fastq1"
                },
                {
                    "$import": "#sequence_to_fastq.cwl/fastq2"
                }
            ],
            "id": "#sequence_to_fastq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Trim FASTQ (flexbar)",
            "baseCommand": [
                "/opt/flexbar/flexbar"
            ],
            "arguments": [
                "--target",
                {
                    "valueFrom": "$(runtime.outdir)/trimmed_read"
                },
                "--threads",
                {
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 25000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bisulfite:v1.4"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--adapter-min-overlap",
                        "position": 3
                    },
                    "id": "#trim_fastq.cwl/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--adapter-trim-end",
                        "position": 2
                    },
                    "id": "#trim_fastq.cwl/adapter_trim_end"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--adapters",
                        "position": 1
                    },
                    "id": "#trim_fastq.cwl/adapters"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--max-uncalled",
                        "position": 5
                    },
                    "id": "#trim_fastq.cwl/max_uncalled"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--min-read-length",
                        "position": 6
                    },
                    "id": "#trim_fastq.cwl/min_readlength"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads",
                        "position": 7
                    },
                    "id": "#trim_fastq.cwl/reads1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads2",
                        "position": 8
                    },
                    "id": "#trim_fastq.cwl/reads2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trimmed_read_1.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastq1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trimmed_read_2.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastq2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "trimmed_read_*.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastqs"
                }
            ],
            "id": "#trim_fastq.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
